function GearEvaluator:InitConfig()
  if (not self.dialogs) then
    self.dialogs = {}
  end

  self:UpdateEvaluatorConfigTable()

  self.configTable.args.profiles = LibStub("AceDBOptions-3.0"):GetOptionsTable(self.db)

  LibStub("AceConfig-3.0"):RegisterOptionsTable("GearEvaluator", self.configTable, { "gearevaluator" })
  self.dialogs.main = LibStub("AceConfigDialog-3.0"):AddToBlizOptions("GearEvaluator", "GearEvaluator", nil, "general")
  self.dialogs.evaluators = LibStub("AceConfigDialog-3.0"):AddToBlizOptions("GearEvaluator", "Evaluators", "GearEvaluator", "evaluators")
  self.dialogs.profiles = LibStub("AceConfigDialog-3.0"):AddToBlizOptions("GearEvaluator", "Profiles", "GearEvaluator", "profiles")
end

function GearEvaluator:UpdateEvaluatorConfigTable()
  -- Delete non-existing entries
  for k, v in pairs(self.evaluatorConfigTable.args) do
    if (k ~= 'add' and not self.db.profile.evaluators[k]) then
      self.evaluatorConfigTable.args[k] = nil
    end
  end

  -- Add new entries
  for k, v in pairs(self.db.profile.evaluators) do
    self.evaluatorConfigTable.args[k] = {
      type = 'group',
      name = k,
      desc = "Options for "..k,
      args = {
        func = {
          name = "Evaluator function",
          type = 'input',
          set = 'UpdateEvaluatorFunction',
          get = 'GetEvaluatorFunction',
          multiline = true,
          width = 'full',
          order = 0
        },
        delete = {
          type = 'execute',
          name = "Delete",
          desc = "Click to delete the "..k.." evaluator",
          func = "DeleteEvaluatorFunction",
          confirm = true,
          confirmText = "You will not be able to undo this action!",
          order = 1
        },
        copy = {
          type = 'select',
          name = 'Copy',
          set = 'CopyEvaluatorFunction',
          values = function() local tbl = {} for k in pairs(self.db.profile.evaluators) do tbl[k] = k end return tbl end,
          order = 2
        },
        rename = {
          type = 'input',
          name = "Rename",
          desc = "Rename this evaluator function",
          get = function(info) return info[#info - 1] end,
          set = 'RenameEvaluatorFunction',
          order = 3
        },
      }
    }
  end
end

GearEvaluator.evaluatorConfigTable = {
  name = "Evaluators",
  type = 'group',
  handler = GearEvaluator,
  childGroups = 'tab',
  args = {
    add = {
      type = 'input',
      name = "Add evaluator",
      set = "AddEvaluatorFunction"
    }
  }
}

GearEvaluator.configTable = {
  name = "GearEvaluator",
  desc = "Evaluates your gear based on certain rules",
  type = 'group',
  args = {
    evaluators = GearEvaluator.evaluatorConfigTable,
    general = {
      type = 'group',
      name = "General",
      args = {
      }
    }
  }
}
