local GearEvaluator = _G.GearEvaluator
local GearEvaluator_BestScore = GearEvaluator:NewModule("BestScore", "AceHook-3.0", "AceEvent-3.0")

function GearEvaluator_BestScore:OnInitialize()
  local defaults = {
    char = {
      bestscores = {},
      sets = {
        ['*'] = {}
      }
    }
  }

  self.db = GearEvaluator.db:RegisterNamespace("BestScore", defaults)
end

function GearEvaluator_BestScore:OnEnable()
  self:RawHook(GearEvaluator, "GetScore")
  self:Hook(GearEvaluator, "UpdateEvaluatorFunction")
  self:Hook(GearEvaluator, "RenameEvaluatorFunction")
end

function GearEvaluator_BestScore:OnDisable()
  self:Unhook(GearEvaluator, "RenameEvaluatorFunction")
  self:Unhook(GearEvaluator, "UpdateEvaluatorFunction")
  self:Unhook(GearEvaluator, "GetScore")
end

function GearEvaluator_BestScore:GetScore(object, evalname, gear)
  local success, score = self.hooks[object].GetScore(object, evalname, gear)

  if (success and score > (self.db.char.bestscores[evalname] or -math.huge)) then
    GearEvaluator:Print("Found best score for '"..evalname.."' - "..score)

    for slot, item in pairs(gear) do
       self.db.char.sets[evalname][slot] = item
    end

    self.db.char.bestscores[evalname] = score
    self:SendMessage("GEAREVALUATOR_BESTSCOREFOUND", evalname, score, gear)
  end

  return success, score
end

function GearEvaluator_BestScore:UpdateEvaluatorFunction(object, info, func)
  self.db.char.bestscores[name] = nil
end

function GearEvaluator_BestScore:GetBestScoreAndGear(evalname)
  return self.db.char.bestscores[evalname], self.db.char.sets[evalname]
end

function GearEvaluator_BestScore:RenameEvaluatorFunction(info, newname)
  name = info[#info - 1]

  if (name == newname) then
    return
  end

  self.db.char.bestscores[newname] = self.db.char.bestscores[name]
  self.db.char.bestscores[name] = nil
end
